//+------------------------------------------------------------------+
//|                                                 SeparationEA.mq4 |
//|                              Copyright  2008, Kevin Mikolajczyk |
//|                                        poolplayer635@hotmail.com |
//+------------------------------------------------------------------+
#property copyright "Copyright  2008, Kevin Mikolajczyk"
#property link      "poolplayer635@hotmail.com"

// Moving Average Inputs
extern int     MAFastPeriod = 6;
extern int     MAFastMode = 1;
extern int     MASlowPeriod = 20;
extern int     MASlowMode = 2;
// Trade Inputs
extern double  Points = 22;
extern double  Lots = 0.1;
extern double  TakeProfit = 30;
extern bool    UseTakeProfit = false;
extern double  StopLoss = 30;
extern bool    UseStopLoss = True;
extern double  Slippage = 3;
extern int     MagicNumber = 13579;
// Money Management Inputs
extern bool    AccountIsMini = true;
extern bool    MoneyManagement = true;
extern double  Risk = 10.0;
extern double  EquityCutoff = 0;
// Internal
double LastValue;
//+------------------------------------------------------------------+
//| expert initialization function                                   |
//+------------------------------------------------------------------+
int init()
{
   return(0);
}
//+------------------------------------------------------------------+
//| expert deinitialization function                                 |
//+------------------------------------------------------------------+
int deinit()
{
   return(0);
}
//+------------------------------------------------------------------+
//| expert start function                                            |
//+------------------------------------------------------------------+
int start()
{
   int cnt;  
   int ticket;
   double Separation;
   double Stop;
   double Profit;

   if (IsNewBar() == false)
   {
      return(0);
   }
   
   cnt = OrdersTotal();
   Separation = (iMA(NULL,0,MAFastPeriod,0,MAFastMode,0,1) - iMA(NULL,0,MASlowPeriod,0,MASlowMode,0,1)) * 1 / Point;
   
   if (cnt > 0)
   {
      OrderSelect(cnt - 1, SELECT_BY_POS, MODE_TRADES);
      
      if (OrderType() == OP_BUY && Separation > Points)
      {
         OrderClose(OrderTicket(), OrderLots(), Bid, Slippage, Red);
      }
      else if (OrderType() == OP_SELL && Separation < -Points)
      {
         OrderClose(OrderTicket(), OrderLots(), Ask, Slippage, Green);
      }
   }
   
   if (Separation > -Points && LastValue < -Points && cnt == 0) //Buy
   {
      if (AccountFreeMargin() < (1000 * LotSize()) || AccountFreeMargin() < EquityCutoff)
      {
         Print("Not enough margin for Buy");
         return(0);
      }
      
      if (UseTakeProfit)
      {
         Profit = Ask + TakeProfit * Point;
      }
      else
      {
         Profit = 0;
      }
         
      if (UseStopLoss)
      {
         Stop = Ask - StopLoss * Point;
      }
      else
      {
         Stop = 0;
      }
                 
      ticket = OrderSend(Symbol(), OP_BUY, LotSize(), Ask, Slippage, Stop, Profit, "", MagicNumber, Green);
     
      if (ticket < 0)
      {
         Print("OrderSend failed with error #", GetLastError());
         return(0);
      }
   }
   else if (Separation < Points && LastValue > Points && cnt == 0) //Sell
   {
      if (AccountFreeMargin() < (1000 * LotSize()) || AccountFreeMargin() < EquityCutoff)
      {
         Print("Not enough margin for Sell");
         return(0);
      }
      
      if (UseTakeProfit)
      {
         Profit = Bid - TakeProfit * Point;
      }
      else
      {
         Profit = 0;
      }
      
      if (UseStopLoss)
      {
         Stop = Bid + StopLoss * Point;
      }
      else
      {
         Stop = 0;
      }
              
      ticket = OrderSend(Symbol(), OP_SELL, LotSize(), Bid, Slippage, Stop, Profit, "", MagicNumber, Red);
     
      if (ticket < 0)
      {
         Print("OrderSend failed with error #", GetLastError());
         return(0);
      }
   }
   
   LastValue = Separation;
   return(0);
}
//Calculates Lot Size
double LotSize()
{
   if (MoneyManagement)
   {
      //Lots = NormalizeDouble(MathFloor(AccountFreeMargin() * Risk / 10000) / 10,1);
      Lots = NormalizeDouble((AccountFreeMargin() / MarketInfo(Symbol(),MODE_MARGINREQUIRED)) * (Risk / 100),1);
      
      if (AccountIsMini)
      {
         Lots = MathFloor(Lots) / 10;    
         if (Lots < 0.1)
         {
            Lots = 0.1;
         }
      }
      
      return(Lots);
   }
   else 
   {   
      Lots = Lots;     
      if (AccountIsMini)
      {
         if (Lots >= 1.0)
         {
            Lots = Lots / 10;
         }
         if (Lots < 0.1)
         {
            Lots = 0.1;
         }
      }
      
      return(Lots);
   }
}
// New Bar Opened
bool IsNewBar()
{
   static datetime lastbar = 0;
   datetime curbar = Time[0];
   
   if (lastbar != curbar)
   {
      lastbar = curbar;
      return(true);
   }
   else
   {
      return(false);
   }
}
//+------------------------------------------------------------------+